<p align="center">
  <img width="250" src="LOGO">
</p>

<h1 align="center"> State Machine code generator </h1>
<p align="center">
  <b>Code generator to create a state machine</b>
</p>
<br>

[![GitHub release](https://img.shields.io/github/release/hellstein/statemachine.svg)](https://github.com/hellstein/statemachine/releases) [![Join the chat at https://gitter.im/statemachine/community](https://badges.gitter.im/statemachine/community.svg)](https://gitter.im/statemachine/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
![Github All Releases](https://img.shields.io/github/downloads/hellstein/statemachine/total.svg)
![Travis (.org) branch](https://img.shields.io/travis/hellstein/statemachine/BRANCH.svg)
![GitHub](https://img.shields.io/github/license/hellstein/statemachine.svg)

# How to use 
Please check the [github page](https://hellstein.github.io/statemachine) for this project.

# How to contribute
* Please check the [github page](https://hellstein.github.io/statemachine) for this project.
* Join the [gitter](https://gitter.im/statemachine/community)

# Logistics
### Code of conduct
For details on our [code of conduct](https://github.com/hellstein/statemachine/blob/master/.github/CODE_OF_CONDUCT.md), and the process for submitting pull requests to us.
### Versioning
We use [SemVer](http://semver.org/) for versioning. For the versions available, see the tags on this repository
### Authors
* **dorrywhale** - *Initial work* - [dorrywhale](https://github.com/dorrywhale)
* See also the list of [contributors](https://github.com/hellstein/statemachine/graphs/contributors) who participated in this project.
### Acknowledgments
See [Acknowledgments](https://github.com/hellstein/statemachine/blob/master/.github/ACKNOWLEDGMENTS.md)
### License
This project is licensed under the MIT License - see the [LICENSE.md](https://github.com/hellstein/statemachine/blob/master/LICENSE.md) file for details
